@@ -1,15 +1,75 @@
 package Locale::Maketext::Extract::Plugin::TextTemplate;
+{
+  $Locale::Maketext::Extract::Plugin::TextTemplate::VERSION = '0.94';
+}
 
 use strict;
 use base qw(Locale::Maketext::Extract::Plugin::Base);
-use vars qw($VERSION);
 
-$VERSION = '0.31';
+# ABSTRACT: Text::Template format parser
+
+
+sub file_types {
+    return qw( * );
+}
+
+sub extract {
+    my $self = shift;
+    local $_ = shift;
+
+    my $line = 1;
+    pos($_) = 0;
+
+    # Text::Template
+    if ( $_ =~ /^STARTTEXT$/m and $_ =~ /^ENDTEXT$/m ) {
+        require HTML::Parser;
+        require Lingua::EN::Sentence;
+
+        {
+
+            package Locale::Maketext::Extract::Plugin::TextTemplate::Parser;
+{
+  $Locale::Maketext::Extract::Plugin::TextTemplate::Parser::VERSION = '0.94';
+}
+            our @ISA = 'HTML::Parser';
+            *{'text'} = sub {
+                my ( $self, $str, $is_cdata ) = @_;
+                my $sentences = Lingua::EN::Sentence::get_sentences($str)
+                    or return;
+                $str =~ s/\n/ /g;
+                $str =~ s/^\s+//;
+                $str =~ s/\s+$//;
+                $self->add_entry( $str, $line );
+            };
+        }
+
+        my $p = Locale::Maketext::Extract::Plugin::TextTemplate::Parser->new;
+        while (m/\G((.*?)^(?:START|END)[A-Z]+$)/smg) {
+            my ($str) = ($2);
+            $line += ( () = ( $1 =~ /\n/g ) );    # cryptocontext!
+            $p->parse($str);
+            $p->eof;
+        }
+        $_ = '';
+    }
+
+}
+
+
+1;
+
+__END__
+
+=pod
 
 =head1 NAME
 
 Locale::Maketext::Extract::Plugin::TextTemplate - Text::Template format parser
 
+=head1 VERSION
+
+version 0.94
+
 =head1 SYNOPSIS
 
     $plugin = Locale::Maketext::Extract::Plugin::TextTemplate->new(
@@ -39,46 +99,6 @@ Sentences between STARTxxx and ENDxxx are extracted individually.
 
 =back
 
-=cut
-
-sub file_types {
-    return qw( * );
-}
-
-
-sub extract {
-    my $self = shift;
-    local $_ = shift;
-
-    my $line = 1; pos($_) = 0;
-
-    # Text::Template
-    if ($_=~/^STARTTEXT$/m and $_=~ /^ENDTEXT$/m) {
-        require HTML::Parser;
-        require Lingua::EN::Sentence;
-
-        {
-            package Locale::Maketext::Extract::Plugin::TextTemplate::Parser;
-            our @ISA = 'HTML::Parser';
-            *{'text'} = sub {
-                my ($self, $str, $is_cdata) = @_;
-                my $sentences = Lingua::EN::Sentence::get_sentences($str) or return;
-                $str =~ s/\n/ /g; $str =~ s/^\s+//; $str =~ s/\s+$//;
-                $self->add_entry($str , $line);
-            };
-        }
-
-        my $p = Locale::Maketext::Extract::Plugin::TextTemplate::Parser->new;
-        while (m/\G((.*?)^(?:START|END)[A-Z]+$)/smg) {
-            my ($str) = ($2);
-            $line += ( () = ($1 =~ /\n/g) ); # cryptocontext!
-            $p->parse($str); $p->eof;
-        }
-        $_ = '';
-    }
-
-}
-
 =head1 SEE ALSO
 
 =over 4
@@ -112,7 +132,7 @@ Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2002-2008 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
+Copyright 2002-2013 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
 
 This software is released under the MIT license cited below.
 
@@ -136,7 +156,26 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Clinton Gormley <drtech@cpan.org>
+
+=item *
+
+Audrey Tang <cpan@audreyt.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Audrey Tang.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
-
-
-1;
