@@ -1,31 +1,13 @@
 package Locale::Maketext::Lexicon::Tie;
-$Locale::Maketext::Lexicon::Tie::VERSION = '0.05';
+{
+  $Locale::Maketext::Lexicon::Tie::VERSION = '0.94';
+}
 
 use strict;
 use Symbol ();
 
-=head1 NAME
+# ABSTRACT: Use tied hashes as lexicons for Maketext
 
-Locale::Maketext::Lexicon::Tie - Use tied hashes as lexicons for Maketext
-
-=head1 SYNOPSIS
-
-    package Hello::I18N;
-    use base 'Locale::Maketext';
-    use Locale::Maketext::Lexicon {
-        en => [ Tie => [ DB_File => 'en.db' ] ],
-    };
-
-=head1 DESCRIPTION
-
-This module lets you easily C<tie> the C<%Lexicon> hash to a database
-or other data sources.  It takes an array reference of arguments, and
-passes them directly to C<tie()>.
-
-Entries will then be fetched whenever it is used; this module does not
-cache them.
-
-=cut
 
 sub parse {
     my $self = shift;
@@ -47,6 +29,35 @@ sub parse {
 
 1;
 
+__END__
+
+=pod
+
+=head1 NAME
+
+Locale::Maketext::Lexicon::Tie - Use tied hashes as lexicons for Maketext
+
+=head1 VERSION
+
+version 0.94
+
+=head1 SYNOPSIS
+
+    package Hello::I18N;
+    use base 'Locale::Maketext';
+    use Locale::Maketext::Lexicon {
+        en => [ Tie => [ DB_File => 'en.db' ] ],
+    };
+
+=head1 DESCRIPTION
+
+This module lets you easily C<tie> the C<%Lexicon> hash to a database
+or other data sources.  It takes an array reference of arguments, and
+passes them directly to C<tie()>.
+
+Entries will then be fetched whenever it is used; this module does not
+cache them.
+
 =head1 SEE ALSO
 
 L<Locale::Maketext>, L<Locale::Maketext::Lexicon>
@@ -57,7 +68,7 @@ Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2002, 2003, 2004, 2007 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
+Copyright 2002-2013 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
 
 This software is released under the MIT license cited below.
 
@@ -81,4 +92,26 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Clinton Gormley <drtech@cpan.org>
+
+=item *
+
+Audrey Tang <cpan@audreyt.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Audrey Tang.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
